package de.hawhamburg.reachability.tools.googleCalendar.json;

import java.util.Set;

import com.google.gdata.data.Category;
import com.google.gdata.data.DateTime;

/**
 * A JSON message which represents an event of the google calendar.<br><br>
 * 
 * This class represents the structure of the JSON messages which describes an event of the google calendar. This 
 * message contains google calendar relevant informations and be send by the 
 * {@link de.hawhamburg.reachability.tools.googleCalendar.GoogleCalendarHookService}.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonGoogleCalendarEvent {
    
    /**
     * The events name as {@link String}.
     */
    public String name;
    
    /**
     * A short description to the event as {@link String} if specified.
     */
    public String description;
    
    /**
     * The location where the event takes place as {@link String} if specified.
     */
    public String location;
    
    /**
     * A {@link Set} of {@link Category}s describing the event if specified.
     */
    public Set<Category> category;
    
    /**
     * An hyperlink as {@link String} which leads, opened within a web browser, to the event.
     */
    public String httpLink;
    
    /**
     * The {@link DateTime} the event starts.
     */
    public DateTime startTime;
    
    /**
     * The {@link DateTime} the event ends.
     */
    public DateTime endTime;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonGoogleCalendarEvent() { }
}
